##  Deleting Fields and Field Values
**Caution**
Exercise caution when deleting fields or field values, as this action can result in data loss.
Deleting fields or field values will temporarily set your workspace to read-only mode. During this period, it’s impossible to make any changes to fact sheets. Typically, the read-only mode lasts no longer than 15 minutes.
To delete a field, select it, click Delete on the right-side panel, then review and save the changes.
To delete a field value for a Multiple Select or Single Select field, click the trash bin icon on this field, then review and save the changes.
